Name:           iml
Version:        1.0.3
Release:        2%{?dist}
Summary:        Finds solutions to systems of linear equations over integers
Group:          Applications/Engineering
License:        BSD
URL:            http://www.cs.uwaterloo.ca/~astorjoh/iml.html
Source0:        http://www.cs.uwaterloo.ca/~astorjoh/iml-%{version}.tar.gz
# This patch will not be sent upstream, as it is Fedora specific.  Configure
# checks whether the system realloc() has either of two bugs and, if so,
# uses a wrapper around realloc() to work around the bugs.  Glibc does not
# have those bugs, so the wrapper is unnecessary.  However, it gets linked
# into the final library anyway.  The wrapper code is GPLv2+ and iml is BSD.
# Since the workaround is not used on Fedora systems anyway, this patch
# prevents it from being linked in, allowing iml to remain straight BSD.
Patch0:         iml-no-repl.patch

BuildRequires:  atlas-devel
BuildRequires:  gmp-devel


%description
IML provides efficient routines to compute exact solutions to dense
systems of linear equations over the integers.  The following
functionality is provided:
- Nonsingular rational system solving.
- Compute the right nullspace of an integer matrix.
- Certified linear system solving.


%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       atlas-devel%{?_isa}, gmp-devel%{?_isa}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        static
Summary:        Static library for %{name}
Group:          Development/Libraries
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}

%description    static
The %{name}-static package contains a static library for %{name}.


%prep
%setup -q
%patch0

# Fix a typo in iml 1.0.3
sed -i 's/mpz_init_ui/mpz_init_set_ui/' src/nullspace.c


%build
%configure --enable-shared \
  --with-atlas-include=%{_includedir}/atlas \
  --with-atlas-lib=%{_libdir}/atlas \
  LDFLAGS="-L%{_libdir}/atlas"

# Remove an unnecessary direct shared library dependency
sed -i 's/ -latlas//' src/Makefile

make %{?_smp_mflags}


%install
make install DESTDIR=$RPM_BUILD_ROOT
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -fr $RPM_BUILD_ROOT%{_datadir}/%{name}


%check
make check


%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%files
%doc AUTHORS README
%{_libdir}/lib%{name}.so.*


%files devel
%doc doc/liblink doc/libroutines examples
%{_includedir}/*
%{_libdir}/lib%{name}.so


%files static
%{_libdir}/lib%{name}.a


%changelog
* Sat Jan  7 2012 Jerry James <loganjerry@gmail.com> - 1.0.3-2
- Rebuild for GCC 4.7

* Wed Oct 26 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.0.3-1.1
- rebuild with new gmp

* Tue Apr 26 2011 Jerry James <loganjerry@gmail.com> - 1.0.3-1
- New upstream release
- Fix URL
- Update description from the web site
- Drop BuildRoot tag, clean script, and clean at start of install script
- Move static library into a -static subpackage
- Fix code typo in iml 1.0.3

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Conrad Meyer <konrad@tylerc.org> - 1.0.2-6
- Fix FTBFS errors.

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Oct 27 2008 Conrad Meyer <konrad@tylerc.org> - 1.0.2-4
- Oops, don't depend on the main package which no longer exists in -devel.

* Fri Oct 17 2008 Conrad Meyer <konrad@tylerc.org> - 1.0.2-2
- Only generate one binary package.
- Add %%check.

* Sun Oct 12 2008 Conrad Meyer <konrad@tylerc.org> - 1.0.2-1
- Initial package.
